@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettings.py 11625 2019-06-10 07:12:00Z Andy $
+# $Id: AttachSettings.py 11646 2019-07-01 01:31:33Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-06-10 15:12:00 +0800 (週一, 10 六月 2019) $
-# $Revision: 11625 $
+# $Date: 2019-07-01 09:31:33 +0800 (週一, 01 七月 2019) $
+# $Revision: 11646 $
 
 import os
 from Iuppiter import Util
@@ -188,9 +188,9 @@ def attachSettings(settingsDict):
         #=======================================================================
 
         # django-modeladmin-reorder
-        middlewareClasses = settingsDict['MIDDLEWARE_CLASSES']
+        middlewareClasses = settingsDict['MIDDLEWARE']
         middlewareClasses += ('admin_reorder.middleware.ModelAdminReorder', )
-        settingsDict['MIDDLEWARE_CLASSES'] = middlewareClasses
+        settingsDict['MIDDLEWARE'] = middlewareClasses
 
         #=======================================================================
         # Attach editor template settings.
