@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 10838 2018-03-12 10:54:45Z David $
+# $Id: urls.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,16 +11,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-12 18:54:45 +0800 (週一, 12 三月 2018) $
-# $Revision: 10838 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 from django.conf import settings
-from django.conf.urls import url, include, patterns
+from django.conf.urls import url, include
 
 #import views
 
-urlpatterns = patterns('', )
+urlpatterns = []
 
 # Newsletter_extension api
 if 'Theophrastus.newsletter_extension' in settings.INSTALLED_APPS:
