@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11642 2019-06-24 02:28:05Z Andy $
+# $Id: forms.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,11 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-06-24 10:28:05 +0800 (週一, 24 六月 2019) $
-# $Revision: 11642 $
+# $Date: 2020-06-19 14:41:16 +0800 (週五, 19 六月 2020) $
+# $Revision: 12366 $
 
 from django import forms
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext as _
 
 from Iuppiter.extension.Widgets import ReadOnlyWidget
