@@ -17,8 +17,8 @@ class Migration(migrations.Migration):
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('message', models.CharField(max_length=2048, null=True, blank=True)),
-                ('contact', models.ForeignKey(verbose_name='contact', to='newsletter.Contact')),
-                ('newsletter', models.ForeignKey(verbose_name='newsletter', to='newsletter.Newsletter')),
+                ('contact', models.ForeignKey(verbose_name='contact', to='newsletter.Contact',on_delete=models.CASCADE)),
+                ('newsletter', models.ForeignKey(verbose_name='newsletter', to='newsletter.Newsletter',on_delete=models.CASCADE)),
             ],
         ),
     ]
