@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: api.py 9579 2016-03-09 01:43:46Z Judy $
+# $Id: api.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,15 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-09 09:43:46 +0800 (週三, 09 三月 2016) $
-# $Revision: 9579 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
-from django.conf.urls import url, patterns
+from django.conf.urls import url
 
 from Theophrastus.newsletter_extension import views
 
-urlpatterns = patterns('',
+urlpatterns = [
     url(r'^newsletter/$', views.getNewsletterInfo,
         name='Theophrastus.newsletter.api.getNewsletterInfo'),
-)
+]
